==> DateTime-Locale-1.27.tar.gz: DateTime-Locale-1.27/share/mi-NZ.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E, d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, dd-MM",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-other" => "'wiki' W 'o' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "dd-MM",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM-y",
    yMEd => "E, dd-MM-y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "dd-MM-y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'wiki' w 'o' Y",
  },
  code => "mi-NZ",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd-MM-y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Hin",
    "T\N{U+016b}",
    "Apa",
    "Par",
    "Mer",
    "Hor",
    "Tap",
  ],
  day_format_narrow => [
    "H",
    "T",
    "A",
    "P",
    "M",
    "H",
    "T",
  ],
  day_format_wide => [
    "R\N{U+0101}hina",
    "R\N{U+0101}t\N{U+016b}",
    "R\N{U+0101}apa",
    "R\N{U+0101}pare",
    "R\N{U+0101}mere",
    "R\N{U+0101}horoi",
    "R\N{U+0101}tapu",
  ],
  day_stand_alone_abbreviated => [
    "Hin",
    "T\N{U+016b}",
    "Apa",
    "Par",
    "Mer",
    "Hor",
    "Tap",
  ],
  day_stand_alone_narrow => [
    "H",
    "T",
    "A",
    "P",
    "M",
    "H",
    "T",
  ],
  day_stand_alone_wide => [
    "R\N{U+0101}hina",
    "R\N{U+0101}t\N{U+016b}",
    "R\N{U+0101}apa",
    "R\N{U+0101}pare",
    "R\N{U+0101}mere",
    "R\N{U+0101}horoi",
    "R\N{U+0101}tapu",
  ],
  era_abbreviated => [
    "BCE",
    "CE",
  ],
  era_narrow => [
    "BCE",
    "CE",
  ],
  era_wide => [
    "BCE",
    "CE",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%d/%m/%y",
  glibc_datetime_format => "Te %A, te %d o %B, %Y %T %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Maori",
  month_format_abbreviated => [
    "Kohi",
    "Hui",
    "Pou",
    "Pae",
    "Hara",
    "Pipi",
    "H\N{U+014d}ngo",
    "Here",
    "Mahu",
    "Nuku",
    "Rangi",
    "Haki",
  ],
  month_format_narrow => [
    "K",
    "H",
    "P",
    "P",
    "H",
    "P",
    "H",
    "H",
    "M",
    "N",
    "R",
    "H",
  ],
  month_format_wide => [
    "Kohit\N{U+0101}tea",
    "Huitanguru",
    "Pout\N{U+016b}terangi",
    "Paengawh\N{U+0101}wh\N{U+0101}",
    "Haratua",
    "Pipiri",
    "H\N{U+014d}ngongoi",
    "Hereturik\N{U+014d}k\N{U+0101}",
    "Mahuru",
    "Whiringa-\N{U+0101}-nuku",
    "Whiringa-\N{U+0101}-rangi",
    "Hakihea",
  ],
  month_stand_alone_abbreviated => [
    "Kohi",
    "Hui",
    "Pou",
    "Pae",
    "Hara",
    "Pipi",
    "H\N{U+014d}ngo",
    "Here",
    "Mahu",
    "Nuku",
    "Rangi",
    "Haki",
  ],
  month_stand_alone_narrow => [
    "K",
    "H",
    "P",
    "P",
    "H",
    "P",
    "H",
    "H",
    "M",
    "N",
    "R",
    "H",
  ],
  month_stand_alone_wide => [
    "Kohit\N{U+0101}tea",
    "Huitanguru",
    "Pout\N{U+016b}terangi",
    "Paengawh\N{U+0101}wh\N{U+0101}",
    "Haratua",
    "Pipiri",
    "H\N{U+014d}ngongoi",
    "Hereturik\N{U+014d}k\N{U+0101}",
    "Mahuru",
    "Whiringa-\N{U+0101}-nuku",
    "Whiringa-\N{U+0101}-rangi",
    "Hakihea",
  ],
  name => "Maori New Zealand",
  native_language => "M\N{U+0101}ori",
  native_name => "M\N{U+0101}ori Aotearoa",
  native_script => undef,
  native_territory => "Aotearoa",
  native_variant => undef,
  quarter_format_abbreviated => [
    "HW1",
    "HW2",
    "HW3",
    "HW4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Hauwh\N{U+0101} tuatahi",
    "Hauwh\N{U+0101} tuarua",
    "Hauwh\N{U+0101} tuatoru",
    "Hauwh\N{U+0101} tuawh\N{U+0101}",
  ],
  quarter_stand_alone_abbreviated => [
    "HW1",
    "HW2",
    "HW3",
    "HW4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Hauwh\N{U+0101} tuatahi",
    "Hauwh\N{U+0101} tuarua",
    "Hauwh\N{U+0101} tuatoru",
    "Hauwh\N{U+0101} tuawh\N{U+0101}",
  ],
  script => undef,
  territory => "New Zealand",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 37,
}

==> DateTime-Locale-1.30.tar.gz: DateTime-Locale-1.30/share/mi-NZ.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E, d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, dd-MM",
    MMM => "LLL",
    MMMEd => "E, d MMM",
    "MMMMW-count-other" => "'wiki' W 'o' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "dd-MM",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM-y",
    yMEd => "E, dd-MM-y",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "dd-MM-y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'wiki' w 'o' Y",
  },
  code => "mi-NZ",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd-MM-y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Hin",
    "T\N{U+016b}",
    "Apa",
    "Par",
    "Mer",
    "Hor",
    "Tap",
  ],
  day_format_narrow => [
    "H",
    "T",
    "A",
    "P",
    "M",
    "H",
    "T",
  ],
  day_format_wide => [
    "R\N{U+0101}hina",
    "R\N{U+0101}t\N{U+016b}",
    "R\N{U+0101}apa",
    "R\N{U+0101}pare",
    "R\N{U+0101}mere",
    "R\N{U+0101}horoi",
    "R\N{U+0101}tapu",
  ],
  day_stand_alone_abbreviated => [
    "Hin",
    "T\N{U+016b}",
    "Apa",
    "Par",
    "Mer",
    "Hor",
    "Tap",
  ],
  day_stand_alone_narrow => [
    "H",
    "T",
    "A",
    "P",
    "M",
    "H",
    "T",
  ],
  day_stand_alone_wide => [
    "R\N{U+0101}hina",
    "R\N{U+0101}t\N{U+016b}",
    "R\N{U+0101}apa",
    "R\N{U+0101}pare",
    "R\N{U+0101}mere",
    "R\N{U+0101}horoi",
    "R\N{U+0101}tapu",
  ],
  era_abbreviated => [
    "BCE",
    "CE",
  ],
  era_narrow => [
    "BCE",
    "CE",
  ],
  era_wide => [
    "BCE",
    "CE",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "Te %A, te %d o %B, %Y %T %Z",
  glibc_date_format => "%d/%m/%y",
  glibc_datetime_format => "Te %A, te %d o %B, %Y %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Maori",
  month_format_abbreviated => [
    "Kohi",
    "Hui",
    "Pou",
    "Pae",
    "Hara",
    "Pipi",
    "H\N{U+014d}ngo",
    "Here",
    "Mahu",
    "Nuku",
    "Rangi",
    "Haki",
  ],
  month_format_narrow => [
    "K",
    "H",
    "P",
    "P",
    "H",
    "P",
    "H",
    "H",
    "M",
    "N",
    "R",
    "H",
  ],
  month_format_wide => [
    "Kohit\N{U+0101}tea",
    "Huitanguru",
    "Pout\N{U+016b}terangi",
    "Paengawh\N{U+0101}wh\N{U+0101}",
    "Haratua",
    "Pipiri",
    "H\N{U+014d}ngongoi",
    "Hereturik\N{U+014d}k\N{U+0101}",
    "Mahuru",
    "Whiringa-\N{U+0101}-nuku",
    "Whiringa-\N{U+0101}-rangi",
    "Hakihea",
  ],
  month_stand_alone_abbreviated => [
    "Kohi",
    "Hui",
    "Pou",
    "Pae",
    "Hara",
    "Pipi",
    "H\N{U+014d}ngo",
    "Here",
    "Mahu",
    "Nuku",
    "Rangi",
    "Haki",
  ],
  month_stand_alone_narrow => [
    "K",
    "H",
    "P",
    "P",
    "H",
    "P",
    "H",
    "H",
    "M",
    "N",
    "R",
    "H",
  ],
  month_stand_alone_wide => [
    "Kohit\N{U+0101}tea",
    "Huitanguru",
    "Pout\N{U+016b}terangi",
    "Paengawh\N{U+0101}wh\N{U+0101}",
    "Haratua",
    "Pipiri",
    "H\N{U+014d}ngongoi",
    "Hereturik\N{U+014d}k\N{U+0101}",
    "Mahuru",
    "Whiringa-\N{U+0101}-nuku",
    "Whiringa-\N{U+0101}-rangi",
    "Hakihea",
  ],
  name => "Maori New Zealand",
  native_language => "te reo M\N{U+0101}ori",
  native_name => "te reo M\N{U+0101}ori Aotearoa",
  native_script => undef,
  native_territory => "Aotearoa",
  native_variant => undef,
  quarter_format_abbreviated => [
    "HW1",
    "HW2",
    "HW3",
    "HW4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Hauwh\N{U+0101} tuatahi",
    "Hauwh\N{U+0101} tuarua",
    "Hauwh\N{U+0101} tuatoru",
    "Hauwh\N{U+0101} tuawh\N{U+0101}",
  ],
  quarter_stand_alone_abbreviated => [
    "HW1",
    "HW2",
    "HW3",
    "HW4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Hauwh\N{U+0101} tuatahi",
    "Hauwh\N{U+0101} tuarua",
    "Hauwh\N{U+0101} tuatoru",
    "Hauwh\N{U+0101} tuawh\N{U+0101}",
  ],
  script => undef,
  territory => "New Zealand",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 38,
}
